@@ -1,18 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2010 Teo Mrnjavac <teo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2010 Teo Mrnjavac <teo@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Lesser General Public
-   License as published by the Free Software Foundation; either
-   version 2.1 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
-
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "kaboutapplicationpersonlistdelegate_p.h"
@@ -21,7 +11,7 @@
 #include "kaboutapplicationpersonlistview_p.h"
 #include "ktoolbar.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QAction>
 #include <QApplication>
@@ -154,7 +144,7 @@ void KAboutApplicationPersonListDelegate::updateItemWidgets(const QList<QWidget
     socialLinks->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
     int currentSocialLinkAction = 0;
-    const auto links = profile.ocsLinks();
+    const auto &links = profile.ocsLinks();
     for (const KAboutApplicationPersonProfileOcsLink &link : links) {
         if (!profile.homepage().isEmpty() && profile.homepage() == link.url()) {
             continue;    //We skip it if it's the same as the homepage from KAboutData
@@ -228,7 +218,7 @@ void KAboutApplicationPersonListDelegate::paint(QPainter *painter,
         KAboutApplicationPersonProfile profile = index.data().value< KAboutApplicationPersonProfile >();
 
         if (!profile.avatar().isNull()) {
-            QPixmap pixmap = profile.avatar();
+            const QPixmap &pixmap = profile.avatar();
 
             point.setX((AVATAR_WIDTH - pixmap.width()) / 2 + 5);
             point.setY(option.rect.top() + ((height - pixmap.height()) / 2));
