@@ -10,12 +10,11 @@
 #include <QDomDocument>
 #include <QAction>
 #include <QMenu>
-#include <QLinkedList>
 #include <QPointer>
 
-#include <kactionmenu.h>
-#include <kauthorized.h>
-#include <klocalizedstring.h>
+#include <KActionMenu>
+#include <KAuthorized>
+#include <KLocalizedString>
 
 #include "kxmlguiwindow.h"
 #include "ktoggletoolbaraction.h"
