@@ -5,17 +5,18 @@
 #include <QDir>
 #include <QTest>
 
-#include <stdlib.h>
+#include <cstdlib>
 
 #include <QAction>
+#include <QActionGroup>
 #include <QApplication>
 #include <QComboBox>
 #include <khelpmenu.h>
 #include <QLineEdit>
 #include <kxmlguifactory.h>
-#include <kactionmenu.h>
 #include <kactioncollection.h>
-#include <ktoggleaction.h>
+#include <KActionMenu>
+#include <KToggleAction>
 
 TestWindow::TestWindow(QWidget *parent)
     : KXmlGuiWindow(parent)
